@@ -12,7 +12,7 @@
 
 
 # Major package imports.
-from PyQt4 import QtGui
+from enthought.qt import QtGui
 
 # Enthought library imports.
 from enthought.traits.api import HasTraits, implements
