@@ -29,7 +29,7 @@ import types
 import traceback
 
 # Major package imports.
-from PyQt4 import QtCore, QtGui
+from PyQt4 import QtCore, QtGui, Qsci
 from PyQt4.Qsci import QsciScintilla, QsciScintillaBase as QsciBase, \
     QsciAbstractAPIs, QsciLexerPython, QsciStyle
 
@@ -212,14 +212,16 @@ elif sys.platform == 'darwin':
     _FONT = 'Monaco'
     _FONT_SIZE = 12
 else:
-    _FONT = 'Courier'
+    _FONT = 'Bitstream Vera Sans Mono'
     _FONT_SIZE = 10
 
-# Determine if the window manager is Metacity (see 'keyPressEvent' for info)
-if sys.platform == 'linux2':
-    METACITY = 'metacity' in Popen(['ps', '-A'], stdout=PIPE).communicate()[0]
+# Determine if fix is needed for QScintilla bug (see 'keyPressEvent' for info)
+if (QtCore.QT_VERSION < 0x040500 or Qsci.QSCINTILLA_VERSION < 0x20401) and \
+        sys.platform == 'linux2':
+    METACITY_FIX = 'metacity' in Popen(['ps', '-A'], 
+                                       stdout=PIPE).communicate()[0]
 else:
-    METACITY = False
+    METACITY_FIX = False
 
 class QConsoleWidget(QsciScintilla):
     """ Specialized styled text control view for console-like workflow.
@@ -569,7 +571,7 @@ class QConsoleWidget(QsciScintilla):
         # Hack around a bug in QScintilla where creating an autocompletion
         # prompt causes the window to lose focus if the application is running
         # under Gnome.
-        if METACITY and not list_active and self.isListActive():
+        if METACITY_FIX and not list_active and self.isListActive():
             for child in self.children():
                 if isinstance(child, QtGui.QListWidget):
                     child.setWindowFlags(QtCore.Qt.ToolTip |
@@ -773,7 +775,7 @@ class QConsoleWidget(QsciScintilla):
         """
         font_metrics = QtGui.QFontMetrics(QtGui.QFont(_FONT, _FONT_SIZE))
         char_width = float(font_metrics.width(' '))
-        self._buffer.width = int(floor(self.viewport().width() / char_width))        
+        self._buffer.width = int(floor(self.viewport().width() / char_width))
 
     def _get_word_start(self, line, index):
         """ Find the start of the word to the left the given position. If a
@@ -781,7 +783,7 @@ class QConsoleWidget(QsciScintilla):
             them. (This emulates the behavior of bash, emacs, etc.)
         """
         if index == self._prompt_index:
-            # Don't let Scintilla get confused by a continuation promot
+            # Don't let Scintilla get confused by a continuation prompt
             line -= 1
             index = self.text(line).length() - 1
 
@@ -936,7 +938,8 @@ example:
                    refresh=False)
         self.write('Type "copyright", "credits" or "license" for more ' \
                        'information.\n', refresh=False)
-        self.write('''Type "?" to see this shell's enhancements.\n''', refresh=False)
+        self.write('Type "?" to see this shell\'s enhancements.\n', 
+                   refresh=False)
         self.new_prompt()
 
         self.SendScintilla(QsciBase.SCI_SETLEXER, QsciBase.SCLEX_PYTHON)
@@ -1058,10 +1061,11 @@ example:
         # Process 'magic' commands
         stripped = source.strip()
         if self._is_magic(stripped, 'cd'):
-            if len(stripped) == 2:
-                path = '~'
+            arg = self._get_magic_argument(stripped, 'cd')
+            if arg:
+                path = self._parse_path(arg)
             else:
-                path = self._parse_path(stripped[2:])
+                path = '~'
             try:
                 os.chdir(os.path.expanduser(path))
             except OSError:
@@ -1072,10 +1076,11 @@ example:
             self.write(os.path.abspath(os.getcwd()) + '\n', refresh=False)
 
         elif self._is_magic(stripped, 'ls'):
-            if len(stripped) == 2:
-                path = os.getcwd()
+            arg = self._get_magic_argument(stripped, 'ls')
+            if arg:
+                path = os.path.expanduser(self._parse_path(arg))
             else:
-                path = os.path.expanduser(self._parse_path(stripped[2:]))
+                path = os.getcwd()
             # FIXME: Check for availability of 'ls' on Windows in __init__
             if sys.platform == 'win32':
                 args = [ 'dir', path.rstrip('/') ]
@@ -1094,16 +1099,17 @@ example:
             self.write(err, refresh=False)
 
         elif self._is_magic(stripped, 'run'):
-            if len(stripped) == 3:
-                self.write('A filename must be provided!\n', refresh=False)
-            else:
-                path = os.path.expanduser(self._parse_path(stripped[4:]))
+            arg = self._get_magic_argument(stripped, 'run')
+            if arg:
+                path = os.path.expanduser(self._parse_path(arg))
                 if not os.path.isfile(path) and not path.endswith('.py'):
                     path += '.py'
                 if os.path.exists(path):
                     self.execute_file(path, hidden)
                 else:
                     self.write('File `%s` not found.\n' % path, refresh=False)
+            else:
+                self.write('A filename must be provided!\n', refresh=False)
 
         elif self._is_magic(stripped, 'who'):
             # The 'who' command prints the names in the namespace.
@@ -1266,12 +1272,22 @@ example:
     def _is_magic(self, string, *magics):
         """ Returns whether a given command string matches a magic command.
         """
+        if string.startswith('%'):
+            string = string[1:]
         for magic in magics:
             if (string.startswith(magic) and 
                 (len(string) == len(magic) or string[len(magic)] == ' ')):
                 return magic
         return False
 
+    def _get_magic_argument(self, string, magic):
+        """ Assuming a given command string is call to the specified magic 
+            command, return the argument to the magic.
+        """
+        if string.startswith('%'):
+            string = string[1:]
+        return string[len(magic):]
+
     def _parse_path(self, string):
         """ Given a path string as specified by a user for a magic command,
             return a cleaned-up path.
