@@ -15,7 +15,7 @@
 from logging import DEBUG
 
 # Major package imports.
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 # Enthought library imports.
 from enthought.traits.api import Any, Bool, Font, implements, Instance, Int
