@@ -13,7 +13,7 @@
 
 
 # Major package imports.
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 # Enthought library imports.
 from enthought.traits.api import Callable, Enum, Float, HasTraits, implements
