@@ -12,7 +12,7 @@
 
 
 # Major package imports.
-from PyQt4 import QtCore
+from enthought.qt import QtCore
 
 
 class Timer(QtCore.QTimer):
