@@ -37,7 +37,8 @@ class Widget(MWidget, HasTraits):
 
     def destroy(self):
         if self.control is not None:
-            self.control.setParent(None)
+            self.control.hide()
+            self.control.deleteLater()
             self.control = None
 
 #### EOF ######################################################################
