@@ -11,7 +11,9 @@
 import sys
 
 # Major library imports.
-from PyQt4 import QtCore, QtGui
+import sip
+from enthought.qt import QtCore, QtGui, Signal
+
 
 class SplitTabWidget(QtGui.QSplitter):
     """ The SplitTabWidget class is a hierarchy of QSplitters the leaves of
@@ -19,6 +21,11 @@ class SplitTabWidget(QtGui.QSplitter):
     automatically extended and reduced as required.
     """
 
+    # Signals for WorkbenchWindowLayout to handle
+    new_window_request = Signal(QtCore.QPoint, QtGui.QWidget)
+    tab_close_request = Signal(QtGui.QWidget)
+    tab_window_changed = Signal(QtGui.QWidget)
+
     # The different hotspots of a QTabWidget.  An non-negative value is a tab
     # index and the hotspot is to the left of it.
     _HS_NONE = -1
@@ -27,6 +34,7 @@ class SplitTabWidget(QtGui.QSplitter):
     _HS_SOUTH = -4
     _HS_EAST = -5
     _HS_WEST = -6
+    _HS_OUTSIDE = -7
 
     def __init__(self, *args):
         """ Initialise the instance. """
@@ -39,9 +47,6 @@ class SplitTabWidget(QtGui.QSplitter):
                 QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
                 self._focus_changed)
         
-        # default close tab callback just closes a control
-        self.close_tab_request_callback = lambda w: w.close()
-
     def clear(self):
         """ Restore the widget to its pristine state. """
 
@@ -180,7 +185,7 @@ class SplitTabWidget(QtGui.QSplitter):
     def _close_tab_request(self, w):
         """ A close button was clicked in one of out _TabWidgets """
         
-        self.close_tab_request_callback(w)
+        self.tab_close_request.emit(w)
 
     def setCurrentWidget(self, w):
         """ Make the given widget current. """
@@ -223,7 +228,7 @@ class SplitTabWidget(QtGui.QSplitter):
     def _tab_widget(self, w):
         """ Return the tab widget and index containing the given widget. """
 
-        for tw in self.findChildren(_TabWidget):
+        for tw in self.findChildren(_TabWidget, None):
             idx = tw.indexOf(w)
 
             if idx >= 0:
@@ -281,9 +286,15 @@ class SplitTabWidget(QtGui.QSplitter):
     def _focus_changed(self, old, new):
         """ Handle a change in focus that affects the current tab. """
 
+        # It is possible for the C++ layer of this object to be deleted between
+        # the time when the focus change signal is emitted and time when the
+        # slots are dispatched by the Qt event loop. This may be a bug in PyQt4.
+        if sip.isdeleted(self):
+            return
+
         if self._repeat_focus_changes:
             self.emit(QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
-                    old, new)
+                      old, new)
 
         if isinstance(new, _DragableTabBar):
             ntw = new.parent()
@@ -297,10 +308,6 @@ class SplitTabWidget(QtGui.QSplitter):
         # See if the widget that has lost the focus is ours.
         otw, _ = self._tab_widget_of(old)
 
-        # XXX this prevents focus changes between different tabs of the same tabwidget
-        #if otw is ntw:
-        #    return
-
         if otw is not None or ntw is not None:
             if ntw is None:
                 nw = None
@@ -314,7 +321,7 @@ class SplitTabWidget(QtGui.QSplitter):
         given widget.
         """
 
-        for tw in self.findChildren(_TabWidget):
+        for tw in self.findChildren(_TabWidget, None):
             for tidx in range(tw.count()):
                 w = tw.widget(tidx)
 
@@ -330,7 +337,7 @@ class SplitTabWidget(QtGui.QSplitter):
 
         if tidx < 0:
             # Find the tab widget logically to the left.
-            twlist = self.findChildren(_TabWidget)
+            twlist = self.findChildren(_TabWidget, None)
             i = twlist.index(tw)
             i -= 1
 
@@ -352,7 +359,7 @@ class SplitTabWidget(QtGui.QSplitter):
 
         if tidx >= tw.count():
             # Find the tab widget logically to the right.
-            twlist = self.findChildren(_TabWidget)
+            twlist = self.findChildren(_TabWidget, None)
             i = twlist.index(tw)
             i += 1
 
@@ -376,29 +383,43 @@ class SplitTabWidget(QtGui.QSplitter):
                 self._rband.hide()
 
             if tw is not None and hs != self._HS_NONE:
-                # Create the rubber band if it hasn't already been done.
-                if self._rband is None:
-                    self._rband = QtGui.QRubberBand(QtGui.QRubberBand.Rectangle)
-
-                self._rband.setGeometry(*hs_geom)
+                if self._rband:
+                    self._rband.deleteLater()
+                position = QtCore.QPoint(*hs_geom[0:2])
+                window = tw.window()
+                self._rband = QtGui.QRubberBand(QtGui.QRubberBand.Rectangle,
+                                                window)
+                self._rband.move(window.mapFromGlobal(position))
+                self._rband.resize(*hs_geom[2:4])
                 self._rband.show()
 
             self._selected_tab_widget = tw
             self._selected_hotspot = hs
 
-    def _drop(self, stab_w, stab):
+    def _drop(self, pos, stab_w, stab):
         self._rband.hide()
 
+        # Get the destination locations.
         dtab_w = self._selected_tab_widget
         dhs = self._selected_hotspot
-
-        # Handle the trivial case.
-        if dtab_w is None or dhs == self._HS_NONE:
+        if dhs == self._HS_NONE:
             return
+        elif dhs != self._HS_OUTSIDE:
+            dsplit_w = dtab_w.parent()
+            while not isinstance(dsplit_w, SplitTabWidget):
+                dsplit_w = dsplit_w.parent()
 
         self._selected_tab_widget = None
         self._selected_hotspot = self._HS_NONE
 
+        # See if the tab is being moved to a new window.
+        if dhs == self._HS_OUTSIDE:
+            # Disable tab tear-out for now. It works, but this is something that
+            # should be turned on manually. We need an interface for this.
+            #ticon, ttext, ttextcolor, twidg = self._remove_tab(stab_w, stab)
+            #self.new_window_request.emit(pos, twidg)
+            return
+
         # See if the tab is being moved to an existing tab widget.
         if dhs >= 0 or dhs == self._HS_AFTER_LAST_TAB:
             # Make sure it really is being moved.
@@ -406,7 +427,7 @@ class SplitTabWidget(QtGui.QSplitter):
                 if stab == dhs:
                     return
 
-                if dhs == self._HS_AFTER_LAST_TAB and stab == stab_w.count() - 1:
+                if dhs == self._HS_AFTER_LAST_TAB and stab == stab_w.count()-1:
                     return
 
             QtGui.qApp.blockSignals(True)
@@ -430,8 +451,8 @@ class SplitTabWidget(QtGui.QSplitter):
                 idx = dtab_w.insertTab(dhs, twidg, ticon, ttext)
                 dtab_w.tabBar().setTabTextColor(idx, ttextcolor)
 
-            # Make the tab current in its new position.
-            self._set_current_tab(dtab_w, idx)
+            dsplit_w._set_current_tab(dtab_w, idx)
+
         else:
             # Ignore drops to the same tab widget when it only has one tab.
             if stab_w is dtab_w and stab_w.count() == 1:
@@ -442,7 +463,7 @@ class SplitTabWidget(QtGui.QSplitter):
             # Remove the tab from its current tab widget and create a new one
             # for it.
             ticon, ttext, ttextcolor, twidg = self._remove_tab(stab_w, stab)
-            new_tw = _TabWidget(self)
+            new_tw = _TabWidget(dsplit_w)
             new_tw.addTab(twidg, ticon, ttext)
             new_tw.tabBar().setTabTextColor(0, ttextcolor)
 
@@ -451,16 +472,21 @@ class SplitTabWidget(QtGui.QSplitter):
             dspl_idx = dspl.indexOf(dtab_w)
 
             if dhs in (self._HS_NORTH, self._HS_SOUTH):
-                dspl, dspl_idx = self._horizontal_split(dspl, dspl_idx, dhs)
+                dspl, dspl_idx = dsplit_w._horizontal_split(dspl, dspl_idx, dhs)
             else:
-                dspl, dspl_idx = self._vertical_split(dspl, dspl_idx, dhs)
+                dspl, dspl_idx = dsplit_w._vertical_split(dspl, dspl_idx, dhs)
 
             # Add the new tab widget in the right place.
             dspl.insertWidget(dspl_idx, new_tw)
 
-            self._set_current_tab(new_tw, 0)
+            dsplit_w._set_current_tab(new_tw, 0)
+        
+        dsplit_w._set_focus()
 
-        self._set_focus()
+        # Signal that the tab's SplitTabWidget has changed, if necessary.
+        if dsplit_w != self:
+            self.tab_window_changed.emit(twidg)
+        
         QtGui.qApp.blockSignals(False)
 
     def _horizontal_split(self, spl, idx, hs):
@@ -536,27 +562,60 @@ class SplitTabWidget(QtGui.QSplitter):
 
     def _hotspot(self, pos):
         """ Return a tuple of the tab widget, hotspot and hostspot geometry (as
-        a list) at the given position.
+        a tuple) at the given position.
         """
+        global_pos = self.mapToGlobal(pos)
         miss = (None, self._HS_NONE, None)
 
-        # Handle the trivial case.
-        if not self.geometry().contains(self.mapToParent(pos)):
-            return miss
+        # Get the bounding rect of the cloned QTbarBar.
+        top_widget = QtGui.qApp.topLevelAt(global_pos)
+        if isinstance(top_widget, QtGui.QTabBar):
+            cloned_rect = top_widget.frameGeometry()
+        else:
+            cloned_rect = None
+        
+        # Determine which visible SplitTabWidget, if any, is under the cursor
+        # (compensating for the cloned QTabBar that may be rendered over it).
+        split_widget = None
+        for top_widget in QtGui.qApp.topLevelWidgets():
+            for split_widget in top_widget.findChildren(SplitTabWidget, None):
+                visible_region = split_widget.visibleRegion()
+                widget_pos = split_widget.mapFromGlobal(global_pos)
+                if cloned_rect and split_widget.geometry().contains(widget_pos):
+                    visible_rect = visible_region.boundingRect()
+                    widget_rect = QtCore.QRect(
+                        split_widget.mapFromGlobal(cloned_rect.topLeft()),
+                        split_widget.mapFromGlobal(cloned_rect.bottomRight()))
+                    if not visible_rect.intersected(widget_rect).isEmpty():
+                        break
+                elif visible_region.contains(widget_pos):
+                    break
+            else:
+                split_widget = None
+            if split_widget:
+                break
+
+        # Handle a drag outside of any split tab widget.
+        if not split_widget:
+            if self.window().frameGeometry().contains(global_pos):
+                return miss
+            else:
+                return (None, self._HS_OUTSIDE, None)
 
         # Go through each tab widget.
-        for tw in self.findChildren(_TabWidget):
-            if tw.geometry().contains(tw.parent().mapFrom(self, pos)):
+        pos = split_widget.mapFromGlobal(global_pos)
+        for tw in split_widget.findChildren(_TabWidget, None):
+            if tw.geometry().contains(tw.parent().mapFrom(split_widget, pos)):
                 break
         else:
             return miss
 
         # See if the hotspot is in the widget area.
         widg = tw.currentWidget()
-
         if widg is not None:
+
             # Get the widget's position relative to its parent.
-            wpos = widg.parent().mapFrom(self, pos)
+            wpos = widg.parent().mapFrom(split_widget, pos)
 
             if widg.geometry().contains(wpos):
                 # Get the position of the widget relative to itself (ie. the
@@ -578,21 +637,21 @@ class SplitTabWidget(QtGui.QSplitter):
                     return (tw, self._HS_NORTH, (gx, gy, w, h / 4))
 
                 if y >= (3 * h) / 4:
-                    return (tw, self._HS_SOUTH, (gx, gy + (3 * h) / 4, w, h / 4))
+                    return (tw, self._HS_SOUTH, (gx, gy + (3*h) / 4, w, h / 4))
 
                 if x < w / 4:
                     return (tw, self._HS_WEST, (gx, gy, w / 4, h))
 
                 if x >= (3 * w) / 4:
-                    return (tw, self._HS_EAST, (gx + (3 * w) / 4, gy, w / 4, h))
+                    return (tw, self._HS_EAST, (gx + (3*w) / 4, gy, w / 4, h))
 
                 return miss
 
         # See if the hotspot is in the tab area.
-        tpos = tw.mapFrom(self, pos)
+        tpos = tw.mapFrom(split_widget, pos)
         tab_bar = tw.tabBar()
-        top_bottom = tw.tabPosition() in (QtGui.QTabWidget.North, QtGui.QTabWidget.South)
-
+        top_bottom = tw.tabPosition() in (QtGui.QTabWidget.North, 
+                                          QtGui.QTabWidget.South)
         for i in range(tw.count()):
             rect = tab_bar.tabRect(i)
 
@@ -648,10 +707,9 @@ class SplitTabWidget(QtGui.QSplitter):
                     gy -= tab_heights
                 return (tw, self._HS_AFTER_LAST_TAB, (gx, gy, w, h))
                 
-                
-
         return miss
 
+
 active_style = """QTabWidget::pane { /* The tab widget frame */
      border: 2px solid #00FF00;
  }
@@ -740,6 +798,7 @@ class _TabWidget(QtGui.QTabWidget):
                 prune = parent
                 parent = prune.parent()
 
+            prune.hide()
             prune.deleteLater()
 
     def tabRemoved(self, idx):
@@ -754,115 +813,10 @@ class _TabWidget(QtGui.QTabWidget):
 
     def _close_tab(self, index):
         """ Close the current tab. """
-        # XXX want to call editor.close() to give editor a chance to react...
 
         self._root._close_tab_request(self.widget(index))
         
 
-class _TabCloseButton(QtGui.QAbstractButton):
-    """ The _TabCloseButton class implements a button that is intended to close
-    the current tab.  It uses the same pixmap as that used to draw the dock
-    widget used for workbench views (in fact the code is based on the original
-    C++ code that implements the same).
-    """
-
-    def __init__(self, *args):
-        """ Initialise the instance. """
-
-        QtGui.QAbstractButton.__init__(self, *args)
-
-        self.setToolTip("Close current tab")
-        self.setFocusPolicy(QtCore.Qt.NoFocus)
-
-        # Get the standard icon and compute the size.  We can do it once here
-        # because the icon will never be changed.
-        sty = self.style()
-
-        icon = sty.standardIcon(QtGui.QStyle.SP_TitleBarCloseButton)
-        pm = icon.pixmap(sty.pixelMetric(QtGui.QStyle.PM_SmallIconSize))
-
-        size = max(pm.width(), pm.height())
-
-        try:
-            # This is Qt v4.3.0 and later.
-            margin = sty.pixelMetric(QtGui.QStyle.PM_DockWidgetTitleBarButtonMargin)
-        except AttributeError:
-            margin = 2
-
-        size += margin * 2
-        self._size_hint = QtCore.QSize(size, size)
-
-        self.setIcon(icon)
-
-    def minimumSizeHint(self):
-        """ Reimplemented to return the minimum size. """
-
-        return self._size_hint
-
-    def sizeHint(self):
-        """ Reimplemented to return the current size. """
-
-        return self._size_hint
-
-    def enterEvent(self, e):
-        """ Reimplemented to redraw the button on entering. """
-
-        self.update()
-        QtGui.QAbstractButton.enterEvent(self, e)
-
-    def leaveEvent(self, e):
-        """ Reimplemented to redraw the button on leaving. """
-
-        self.update()
-        QtGui.QAbstractButton.leaveEvent(self, e)
-
-    def paintEvent(self, e):
-        """ Reimplemented to paint the button. """
-
-        p = QtGui.QPainter(self)
-        r = self.rect()
-        sty = self.style()
-
-        opt = QtGui.QStyleOption()
-        opt.initFrom(self)
-        opt.state |= QtGui.QStyle.State_AutoRaise
-
-        if self.isChecked():
-            opt.state |= QtGui.QStyle.State_On
-        elif self.isDown():
-            opt.state |= QtGui.QStyle.State_Sunken
-        elif self.isEnabled() and self.underMouse():
-            opt.state |= QtGui.QStyle.State_Raised
-
-        # Create the gaps by adjusting the size.
-        r.adjust(0, 0, -4, -4)
-        opt.rect.adjust(0, 0, -4, -4)
-
-        sty.drawPrimitive(QtGui.QStyle.PE_PanelButtonTool, opt, p, self)
-
-        if opt.state & QtGui.QStyle.State_Sunken:
-            hshift = sty.pixelMetric(QtGui.QStyle.PM_ButtonShiftHorizontal, opt, self)
-            vshift = sty.pixelMetric(QtGui.QStyle.PM_ButtonShiftVertical, opt, self)
-
-            r.translate(hshift, vshift)
-
-        if self.isEnabled():
-            if self.underMouse():
-                mode = QtGui.QIcon.Active
-            else:
-                mode = QtGui.QIcon.Normal
-        else:
-            mode = QtGui.QIcon.Disabled
-
-        if self.isDown():
-            state = QtGui.QIcon.On
-        else:
-            state = QtGui.QIcon.Off
-
-        pm = self.icon().pixmap(sty.pixelMetric(QtGui.QStyle.PM_SmallIconSize), mode, state)
-        sty.drawItemPixmap(p, r, QtCore.Qt.AlignCenter, pm)
-
-
 class _DragableTabBar(QtGui.QTabBar):
     """ The _DragableTabBar class is a QTabBar that can be dragged around. """
 
@@ -987,10 +941,10 @@ class _DragState(object):
         tab = self._tab
 
         ctb = self._clone = QtGui.QTabBar()
-        # XXX this requires Qt > 4.5
-        if sys.platform == 'darwin':
-            self.setDocumentMode(True)
-            
+        if sys.platform == 'darwin' and QtCore.QT_VERSION >= 0x40500:
+            ctb.setDocumentMode(True)
+          
+        ctb.setAttribute(QtCore.Qt.WA_TransparentForMouseEvents)
         ctb.setWindowFlags(QtCore.Qt.FramelessWindowHint |
                            QtCore.Qt.Tool |
                            QtCore.Qt.X11BypassWindowManagerHint)
@@ -1018,7 +972,8 @@ class _DragState(object):
         """ Handle the movement of the cloned tab during dragging. """
 
         self._clone.move(self._tab_bar.mapToGlobal(pos) + self._clone_offset)
-        self._root._select(self._tab_bar.mapTo(self._root, pos + self._centre_offset))
+        self._root._select(self._tab_bar.mapTo(self._root,
+                                               pos + self._centre_offset))
 
     def drop(self, pos):
         """ Handle the drop of the cloned tab. """
@@ -1026,6 +981,7 @@ class _DragState(object):
         self.drag(pos)
         self._clone = None
 
-        self._root._drop(self._tab_bar.parent(), self._tab)
+        global_pos = self._tab_bar.mapToGlobal(pos)
+        self._root._drop(global_pos, self._tab_bar.parent(), self._tab)
 
         self.dragging = False
