@@ -15,7 +15,7 @@
 import logging
 
 # Major package imports.
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 # Enthought library imports.
 from enthought.traits.api import Instance, on_trait_change
@@ -126,8 +126,11 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         return view
 
     def close(self):
+        # Don't fire signals for editors that have destroyed their controls.
+        QtCore.QObject.disconnect(self._qt4_editor_area, 
+                QtCore.SIGNAL('hasFocus'), self._qt4_editor_focus)
+
         self._qt4_editor_area.clear()
-        self._qt4_editor_area.close_tab_request_callback = None
 
         # Delete all dock widgets.
         for v in self.window.views:
@@ -135,21 +138,23 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                 self._qt4_delete_view_dock_widget(v)
 
     def create_initial_layout(self, parent):
-        self._qt4_editor_area = SplitTabWidget(parent)
+        self._qt4_editor_area = editor_area = SplitTabWidget(parent)
 
-        QtCore.QObject.connect(self._qt4_editor_area,
-                QtCore.SIGNAL('hasFocus'), self._qt4_editor_focus)
+        QtCore.QObject.connect(editor_area, QtCore.SIGNAL('hasFocus'), 
+                               self._qt4_editor_focus)
 
         # We are interested in focus changes but we get them from the editor
         # area rather than qApp to allow the editor area to restrict them when
         # needed.
-        QtCore.QObject.connect(self._qt4_editor_area,
-                QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
-                self._qt4_view_focus_changed)
+        QtCore.QObject.connect(
+            editor_area, QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
+            self._qt4_view_focus_changed)
         
-        self._qt4_editor_area.close_tab_request_callback = self._qt4_tab_close_request
+        editor_area.new_window_request.connect(self._qt4_new_window_request)
+        editor_area.tab_close_request.connect(self._qt4_tab_close_request)
+        editor_area.tab_window_changed.connect(self._qt4_tab_window_changed)
 
-        return self._qt4_editor_area
+        return editor_area
 
     def contains_view(self, view):
         return hasattr(view, '_qt4_dock')
@@ -266,8 +271,8 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                 return None
 
             # Create the restored editor.
-            editor = self.window.editor_manager.set_editor_memento(editor_memento)
-
+            editor = self.window.editor_manager.set_editor_memento(
+                editor_memento)
             if editor is None:
                 return None
 
@@ -287,23 +292,9 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         """ Handle an editor getting the focus. """
 
         for editor in self.window.editors:
-            editor.has_focus = (editor.control is new) or (new in editor.control.children())
-
-    @on_trait_change('window.active_editor')
-    def _qt4_active_editor_changed(self, obj, trait_name, old, new):
-        """ Handle the change of active editor. """
-        
-        # Do we need to do this verification?
-        if obj is not self.window or trait_name != 'active_editor':
-            return
-
-        for editor in self.window.editors:
-            if editor is old:
-                tw, tidx = self._qt4_editor_area._tab_widget(editor.control)
-                tw.setTabText(tidx, editor.name)
-            elif editor is new:
-                tw, tidx = self._qt4_editor_area._tab_widget(editor.control)
-                tw.setTabText(tidx, u'\u25b6' + editor.name)
+            control = editor.control
+            editor.has_focus = control is new or \
+                (control is not None and new in control.children())
 
     def _qt4_view_focus_changed(self, old, new):
         """ Handle the change of focus for a view. """
@@ -324,6 +315,21 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                 if view is not focus_part and view.control is not None and view.control.isAncestorOf(old):
                     view.has_focus = False
                     break
+
+    def _qt4_new_window_request(self, pos, control):
+        """ Handle a tab tear-out request from the splitter widget. """
+        
+        editor = self._qt4_remove_editor_with_control(control)
+        kind = self.window.editor_manager.get_editor_kind(editor)
+
+        window = self.window.workbench.create_window()
+        window.open()
+        window.add_editor(editor)
+        window.editor_manager.add_editor(editor, kind)
+        window.position = (pos.x(), pos.y())
+        window.size = self.window.size
+        window.activate_editor(editor)
+        editor.window = window
     
     def _qt4_tab_close_request(self, control):
         """ Handle a tabCloseRequest from the splitter widget. """
@@ -333,6 +339,39 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                 editor.close()
                 break
 
+    def _qt4_tab_window_changed(self, control):
+        """ Handle a tab drag to a different WorkbenchWindow. """
+
+        editor = self._qt4_remove_editor_with_control(control)
+        kind = self.window.editor_manager.get_editor_kind(editor)
+        
+        while not control.isWindow():
+            control = control.parent()
+        for window in self.window.workbench.windows:
+            if window.control == control:
+                window.editors.append(editor)
+                window.editor_manager.add_editor(editor, kind)
+                window.layout._qt4_get_editor_control(editor)
+                window.activate_editor(editor)
+                editor.window = window
+                break
+
+    def _qt4_remove_editor_with_control(self, control):
+        """ Finds the editor associated with 'control' and removes it. Returns
+            the editor, or None if no editor was found.
+        """
+        for editor in self.window.editors:
+            if editor.control == control:
+                self.editor_closing = editor
+                control.removeEventFilter(self._qt4_mon)
+                self.editor_closed = editor
+                
+                # Make sure that focus events get fired if this editor is
+                # subsequently added to another window.
+                editor.has_focus = False
+
+                return editor
+
     def _qt4_get_editor_control(self, editor):
         """ Create the editor control if it hasn't already been done. """
 
@@ -345,15 +384,14 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             # QSplitter).
             editor.control = editor.create_control(self.window.control)
             editor.control.setObjectName(editor.id)
-            self._qt4_adjust_widget_layout(editor.control)
-
-            def on_name_changed(editor, trait_name, old, new):
-                self._qt4_editor_area.setWidgetTitle(editor.control, editor.name)
-
-            editor.on_trait_change(on_name_changed, 'name')
 
             self.editor_opened = editor
 
+        def on_name_changed(editor, trait_name, old, new):
+            self._qt4_editor_area.setWidgetTitle(editor.control, editor.name)
+
+        editor.on_trait_change(on_name_changed, 'name')
+
         self._qt4_monitor(editor.control)
 
         return editor.control
@@ -445,7 +483,6 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                 del dw
                 raise
 
-        self._qt4_adjust_widget_layout(view.control)
         dw.widget().setCentralWidget(view.control)
 
         return dw
@@ -478,26 +515,6 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             if dw.toggleViewAction() is dw.sender():
                 v.visible = checked
 
-    @staticmethod
-    def _qt4_adjust_widget_layout(w):
-        """ Adjust the layout of a widget so that it appears at the top with
-        with standard margins.
-        """
-        lay = w.layout()
-        
-        # XXX I don't think we should do this... CJW
-
-        #if lay is not None:
-        #    lay.setAlignment(QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
-
-        #    sty = w.style()
-        #    l = sty.pixelMetric(QtGui.QStyle.PM_LayoutLeftMargin)
-        #    t = sty.pixelMetric(QtGui.QStyle.PM_LayoutTopMargin)
-        #    r = sty.pixelMetric(QtGui.QStyle.PM_LayoutRightMargin)
-        #    b = sty.pixelMetric(QtGui.QStyle.PM_LayoutBottomMargin)
-        #    lay.setContentsMargins(l, t, r, b)
-        #    lay.setContentsMargins(0, 0, 0, 0)
-
     def _qt4_monitor(self, control):
         """ Install an event filter for a view or editor control to keep an eye
         on certain events.
@@ -508,7 +525,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             mon = self._qt4_mon
         except AttributeError:
             mon = self._qt4_mon = _Monitor(self)
-
+            
         control.installEventFilter(mon)
 
 
