@@ -16,10 +16,9 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
     
-from enthought.traits.api \
-    import Unicode
+from enthought.traits.api import Unicode, List, Str, on_trait_change
 
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
 # compatibility. The class has been moved to the 
@@ -27,8 +26,7 @@ from enthought.traits.api \
 from enthought.traits.ui.editors.button_editor \
     import ToolkitEditorFactory
 
-from editor \
-    import Editor
+from editor import Editor
 
 #-------------------------------------------------------------------------------
 #  'SimpleEditor' class:
@@ -45,6 +43,12 @@ class SimpleEditor ( Editor ):
     # The button label
     label = Unicode
 
+    # The list of items in a drop-down menu, if any
+    #menu_items = List
+
+    # The selected item in the drop-down menu.
+    selected_item = Str
+
     #---------------------------------------------------------------------------
     #  Finishes initializing the editor by creating the underlying toolkit
     #  widget:
@@ -54,41 +58,59 @@ class SimpleEditor ( Editor ):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
-        label = self.factory.label or self.item.get_label( self.ui )
-        self.control = QtGui.QPushButton(self.string_value(label))
-        self.control.setAutoDefault(False)
-        self.sync_value( self.factory.label_value, 'label', 'from' )
-        QtCore.QObject.connect(self.control, QtCore.SIGNAL('clicked()'),
-                self.update_object )
+        label = self.factory.label or self.item.get_label(self.ui)
+        
+        if self.factory.values_trait:
+            self.control = QtGui.QToolButton()
+            self.control.toolButtonStyle = QtCore.Qt.ToolButtonTextOnly
+            self.control.setText(self.string_value(label))
+            self.object.on_trait_change(self._update_menu, self.factory.values_trait)
+            self.object.on_trait_change(self._update_menu, self.factory.values_trait + "_items")
+            self._menu = QtGui.QMenu()
+            self._update_menu()
+            self.control.setMenu(self._menu)
+
+        else:
+            self.control = QtGui.QPushButton(self.string_value(label))
+            self._menu = None
+            self.control.setAutoDefault(False)
+
+        self.sync_value(self.factory.label_value, 'label', 'from')
+        self.control.clicked.connect(self.update_object)
         self.set_tooltip()
+        
 
-    #---------------------------------------------------------------------------
-    #  Handles the 'label' trait being changed:
-    #---------------------------------------------------------------------------
-
-    def _label_changed ( self, label ):
+    def _label_changed(self, label):
         self.control.setText(self.string_value(label))
 
-    #---------------------------------------------------------------------------
-    #  Handles the user clicking the button by setting the value on the object:
-    #---------------------------------------------------------------------------
+    def _update_menu(self):
+        self._menu.blockSignals(True)
+        self._menu.clear()
+        for item in getattr(self.object, self.factory.values_trait):
+            action = self._menu.addAction(item)
+            action.triggered.connect(lambda event, name=item: self._menu_selected(name))
+        self.selected_item = ""
+        self._menu.blockSignals(False)
 
-    def update_object (self):
+    def _menu_selected(self, item_name):
+        self.selected_item = item_name
+        self.label = item_name
+
+    def update_object(self):
         """ Handles the user clicking the button by setting the factory value
             on the object.
         """
-        self.value = self.factory.value
+        if self.selected_item != "":
+            self.value = self.selected_item
+        else:
+            self.value = self.factory.value
 
         # If there is an associated view, then display it:
         if (self.factory is not None) and (self.factory.view is not None):
             self.object.edit_traits( view   = self.factory.view,
                                      parent = self.control )
 
-    #---------------------------------------------------------------------------
-    #  Updates the editor when the object trait changes external to the editor:
-    #---------------------------------------------------------------------------
-
-    def update_editor ( self ):
+    def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
