@@ -20,7 +20,7 @@ using pickle.
 from cPickle import dumps, load, loads
 from cStringIO import StringIO
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.traits.api import HasTraits, Instance, Property
 
@@ -32,7 +32,7 @@ class PyMimeData(QtCore.QMimeData):
     """ The PyMimeData wraps a Python instance as MIME data.
     """
     # The MIME type for instances.
-    MIME_TYPE = QtCore.QString('application/x-ets-qt4-instance')
+    MIME_TYPE = 'application/x-ets-qt4-instance'
 
     def __init__(self, data=None):
         """ Initialise the instance.
