@@ -16,7 +16,7 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtGui
+from enthought.qt import QtGui
 
 from enthought.traits.api \
     import Trait, TraitError
