@@ -17,7 +17,7 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.traits.api \
     import HasTraits, Property
