@@ -18,7 +18,7 @@ key binding editor).
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.traits.api \
     import Bool, Event
