@@ -16,7 +16,7 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore
+from enthought.qt import QtCore
     
 #-------------------------------------------------------------------------------
 #  Constants:  
