@@ -16,11 +16,11 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.pyface.api import ImageResource
 
-from enthought.traits.api import Str, Any, Bool
+from enthought.traits.api import Str, Any, Bool, Dict
 from enthought.traits.trait_base import user_name_for, enumerate, xgetattr
     
 # FIXME: ToolkitEditorFactory is a proxy class defined here just for backward
@@ -157,22 +157,20 @@ class SimpleEditor ( Editor ):
 
         list_pane = self._list_pane
         layout = list_pane.layout()
-
+        
         # Create all of the list item trait editors:
         trait_handler = self._trait_handler
         resizable     = ((trait_handler.minlen != trait_handler.maxlen) and
                          self.mutable)
         item_trait    = trait_handler.item_trait
-        values        = self.value
-        index         = 0
 
-        is_fake = (resizable and (len( values ) == 0))
+        is_fake = (resizable and (len( self.value ) == 0))
         if is_fake:
            self.empty_list()
 
         editor = self._editor
         # FIXME: Add support for more than one column.
-        for value in values:
+        for index, value in enumerate(self.value):
             if resizable:
                 control = IconButton('list_editor.png', self.popup_menu)
                 layout.addWidget(control, index, 0)
@@ -192,8 +190,6 @@ class SimpleEditor ( Editor ):
             else:
                 layout.addLayout(pcontrol, index, 1)
 
-            index += 1
-
         # QScrollArea can have problems if the widget being scrolled is set too
         # early (ie. before it contains something).
         if self.control.widget() is None:
@@ -271,12 +267,17 @@ class SimpleEditor ( Editor ):
     def popup_menu ( self ):
         """ Displays the list editor popup menu.
         """
-        self._cur_control = control = self.control.sender()
-        proxy    = control.proxy
+        layout = self._list_pane.layout()
+        sender = layout.sender()
+        
+        self._cur_control = sender
+        
+        proxy    = sender.proxy
         index    = proxy.index
-        menu     = MakeMenu( self.list_menu, self, True, control ).menu
+        menu     = MakeMenu( self.list_menu, self, True, sender ).menu
         len_list = len( proxy.list )
         not_full = (len_list < self._trait_handler.maxlen)
+        
         self._menu_before.enabled( not_full )
         self._menu_after.enabled(  not_full )
         self._menu_delete.enabled( len_list > self._trait_handler.minlen )
@@ -284,7 +285,8 @@ class SimpleEditor ( Editor ):
         self._menu_top.enabled( index > 0 )
         self._menu_down.enabled(   index < (len_list - 1) )
         self._menu_bottom.enabled( index < (len_list - 1) )
-        menu.exec_(control.mapToGlobal(QtCore.QPoint(0, 0)))
+        
+        menu.exec_(sender.mapToGlobal(QtCore.QPoint(0, 0)))
 
     #---------------------------------------------------------------------------
     #  Adds a new value at the specified list index:
@@ -479,6 +481,15 @@ class NotebookEditor ( Editor ):
     # The currently selected notebook page object:
     selected = Any
 
+    # Maps tab names to QWidgets representing the tab contents
+    # TODO: It would be nice to be able to reuse self._pages for this, but
+    # its keys are not quite what we want.
+    _pagewidgets = Dict
+    
+    # Maps names of tabs to their menu QAction instances; used to toggle
+    # checkboxes
+    _action_dict = Dict
+
     #---------------------------------------------------------------------------
     #  Finishes initializing the editor by creating the underlying toolkit
     #  widget:
@@ -506,6 +517,13 @@ class NotebookEditor ( Editor ):
             signal = QtCore.SIGNAL( 'clicked()' )
             QtCore.QObject.connect( button, signal, self.close_current )
 
+        if self.factory.show_notebook_menu:
+            # Create the necessary attributes to manage hiding and revealing of
+            # tabs via a context menu
+            self._context_menu = QtGui.QMenu()
+            self.control.customContextMenuRequested.connect(self._context_menu_requested)
+            self.control.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
+
         # Set up the additional 'list items changed' event handler needed for
         # a list based trait:
         self.context_object.on_trait_change( self.update_editor_item,
@@ -552,6 +570,13 @@ class NotebookEditor ( Editor ):
             ui.dispose()
             self.control.removeTab(self.control.indexOf(page))
 
+            if self.factory.show_notebook_menu:
+                for name,tmp in self._pagewidgets.items():
+                    if tmp is page:
+                        del self._pagewidgets[name]
+                self._context_menu.removeAction(self._action_dict[name])
+                del self._action_dict[name]
+
             del self._uis[index]
 
         # Add a page for each added object:
@@ -582,6 +607,23 @@ class NotebookEditor ( Editor ):
                     del self.value[i]
                 break
 
+        if self.factory.show_notebook_menu:
+            # Find the name associated with this widget, so we can purge its action
+            # from the menu
+            for name, tmp in self._pagewidgets.items():
+                if tmp is widget:
+                    break
+            else:
+                # Hmm... couldn't find the widget, assume that we don't need to do
+                # anything.
+                return
+
+            action = self._action_dict[name]
+            self._context_menu.removeAction(action)
+            del self._action_dict[name]
+            del self._pagewidgets[name]
+        return
+
     #---------------------------------------------------------------------------
     #  Closes all currently open notebook pages:
     #---------------------------------------------------------------------------
@@ -699,11 +741,16 @@ class NotebookEditor ( Editor ):
         else:
             self.control.addTab(ui.control, image, name)
 
-        return (ui, view_object, monitoring)                        
+        if self.factory.show_notebook_menu:
+            newaction = self._context_menu.addAction(name)
+            newaction.setText(name)
+            newaction.setCheckable(True)
+            newaction.setChecked(True)
+            newaction.triggered.connect(lambda e,name=name: self._menu_action(e,name=name))
+            self._action_dict[name] = newaction
+            self._pagewidgets[name] = ui.control
 
-    #---------------------------------------------------------------------------
-    #  Handles a notebook tab being 'activated' (i.e. clicked on) by the user:
-    #---------------------------------------------------------------------------
+        return (ui, view_object, monitoring)                        
 
     def _tab_activated(self, idx):
         """ Handles a notebook tab being "activated" (i.e. clicked on) by the
@@ -714,11 +761,6 @@ class NotebookEditor ( Editor ):
             if page is widget:
                 self.selected = ui.info.object
                 break
-
-    #---------------------------------------------------------------------------
-    #  Handles the 'selected' trait being changed:
-    #---------------------------------------------------------------------------
-
     def _selected_changed(self, selected):
         """ Handles the **selected** trait being changed.
         """
@@ -726,3 +768,22 @@ class NotebookEditor ( Editor ):
             if ui.info and selected is ui.info.object:
                 self.control.setCurrentWidget(page)
                 break
+
+    def _context_menu_requested(self, event):
+        self._context_menu.popup(self.control.mapToGlobal(event))
+
+    def _menu_action(self, event, name=""):
+        """ Qt signal handler for when a item in a context menu is actually
+        selected.  Not that we get this even after the underlying value has
+        already changed.
+        """
+        action = self._action_dict[name]
+        checked = action.isChecked()
+        if not checked:
+            for ndx in range(self.control.count()):
+                if self.control.tabText(ndx) == name:
+                    self.control.removeTab(ndx)
+        else:
+            # TODO: Fix tab order based on the context_object's list
+            self.control.addTab(self._pagewidgets[name], name)
+
