@@ -23,7 +23,7 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.pyface.image_resource import ImageResource
 
