@@ -22,7 +22,7 @@
 #  Imports:
 #-------------------------------------------------------------------------------
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.traits.ui.ui_traits import SequenceTypes
 
