@@ -18,36 +18,19 @@
 
 import copy
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
-from enthought.pyface.resource_manager \
-    import resource_manager
-
-from enthought.traits.api \
-    import Any, Event
-
-from enthought.traits.trait_base \
-    import enumerate
-
-from enthought.traits.ui.api \
-    import TreeNode, ObjectTreeNode, MultiTreeNode
-     
-from enthought.traits.ui.undo \
-    import ListUndoItem
-    
+from enthought.pyface.resource_manager import resource_manager
+from enthought.traits.api import Any, Event
+from enthought.traits.trait_base import enumerate
+from enthought.traits.ui.api import TreeNode, ObjectTreeNode, MultiTreeNode
+from enthought.traits.ui.undo import ListUndoItem
 from enthought.traits.ui.tree_node import ITreeNodeAdapterBridge    
+from enthought.traits.ui.menu import Menu, Action, Separator
 
-from enthought.traits.ui.menu \
-    import Menu, Action, Separator
-
-from clipboard \
-    import clipboard, PyMimeData
-
-from editor \
-    import Editor
-
-from helper \
-    import open_fbi, pixmap_cache
+from clipboard import clipboard, PyMimeData
+from editor import Editor
+from helper import open_fbi, pixmap_cache
 
 #-------------------------------------------------------------------------------
 #  The core tree node menu actions:
@@ -360,7 +343,8 @@ class SimpleEditor ( Editor ):
         id_object = id(object)
         object_info = self._map[id_object]
         for i, info in enumerate(object_info):
-            if nid == info[1]:
+            # QTreeWidgetItem does not have an equal operator, so use id()
+            if id(nid) == id(info[1]):
                 del object_info[i]
                 break
 
@@ -861,16 +845,17 @@ class SimpleEditor ( Editor ):
 
         selected = []
         if len(nids) > 0:
-            for n in nids:
+            for nid in nids:
                 # If there is a real selection, get the associated object:
-                expanded, node, sel_object = self._get_node_data(n)
+                expanded, node, sel_object = self._get_node_data(nid)
                 selected.append(sel_object)
 
                 # Try to inform the node specific handler of the selection, if
                 # there are multiple selections, we only care about the first
                 # (or maybe the last makes more sense?)
-                if n == nids[0]:
-                    nid = n
+                
+                # QTreeWidgetItem does not have an equal operator, so use id()                
+                if id(nid) == id(nids[0]):
                     object = sel_object
                     not_handled = node.select(sel_object)
         else:
