@@ -14,7 +14,7 @@
 """
 
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.traits.api \
     import HasStrictTraits, HasPrivateTraits, Instance, List, Event
@@ -277,6 +277,9 @@ class _StickyDialog(QtGui.QDialog):
             layout.setSizeConstraint(QtGui.QLayout.SetFixedSize)
         try:
             flags |= QtCore.Qt.WindowCloseButtonHint
+            if ui.view.resizable:
+                flags |= (QtCore.Qt.WindowMinimizeButtonHint | 
+                          QtCore.Qt.WindowMaximizeButtonHint)
         except AttributeError:
             # Either PyQt or Qt is too old.
             pass
