@@ -14,7 +14,7 @@
 """
 
 
-from PyQt4 import QtCore, QtGui
+from enthought.qt import QtCore, QtGui
 
 from enthought.traits.ui.undo \
     import UndoHistory
